@@ -26,6 +26,7 @@ import sqlalchemy_dhis2 as module
 from sqlalchemy_dhis2.constants import _HEADER
 from sqlalchemy_dhis2.exceptions import DatabaseHTTPError
 from .connection import add_authorization
+from .polars_extensions import FlattenFrame
 
 import re
 import warnings
@@ -311,7 +312,8 @@ class JSONHTTPDialect(DefaultDialect):
         preload_extensions = cparams.pop("preload_extensions", [])
         config = cparams.setdefault("config", {})
         config.update(cparams.pop("url_config", {}))
-
+        config.pop('collection','')
+        
         ext = {k: config.pop(k) for k in list(config) if k not in core_keys}
         #if supports_user_agent:
         #    user_agent = f"duckdb_engine/{__version__}(sqlalchemy/{sqlalchemy_version})"
